@@ -16,24 +16,27 @@
 #
 
 from .cloud_tts import (
+    AudioConfig,
     ListVoicesRequest,
     ListVoicesResponse,
-    Voice,
-    SynthesizeSpeechRequest,
     SynthesisInput,
-    VoiceSelectionParams,
-    AudioConfig,
+    SynthesizeSpeechRequest,
     SynthesizeSpeechResponse,
+    Voice,
+    VoiceSelectionParams,
+    AudioEncoding,
+    SsmlVoiceGender,
 )
 
-
 __all__ = (
+    "AudioConfig",
     "ListVoicesRequest",
     "ListVoicesResponse",
-    "Voice",
-    "SynthesizeSpeechRequest",
     "SynthesisInput",
-    "VoiceSelectionParams",
-    "AudioConfig",
+    "SynthesizeSpeechRequest",
     "SynthesizeSpeechResponse",
+    "Voice",
+    "VoiceSelectionParams",
+    "AudioEncoding",
+    "SsmlVoiceGender",
 )
