@@ -30,7 +30,7 @@ from google.oauth2 import service_account  # type: ignore
 
 from google.cloud.texttospeech_v1beta1.types import cloud_tts
 
-from .transports.base import TextToSpeechTransport
+from .transports.base import TextToSpeechTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc_asyncio import TextToSpeechGrpcAsyncIOTransport
 from .client import TextToSpeechClient
 
@@ -43,9 +43,72 @@ class TextToSpeechAsyncClient:
     DEFAULT_ENDPOINT = TextToSpeechClient.DEFAULT_ENDPOINT
     DEFAULT_MTLS_ENDPOINT = TextToSpeechClient.DEFAULT_MTLS_ENDPOINT
 
-    from_service_account_file = TextToSpeechClient.from_service_account_file
+    common_billing_account_path = staticmethod(
+        TextToSpeechClient.common_billing_account_path
+    )
+    parse_common_billing_account_path = staticmethod(
+        TextToSpeechClient.parse_common_billing_account_path
+    )
+
+    common_folder_path = staticmethod(TextToSpeechClient.common_folder_path)
+    parse_common_folder_path = staticmethod(TextToSpeechClient.parse_common_folder_path)
+
+    common_organization_path = staticmethod(TextToSpeechClient.common_organization_path)
+    parse_common_organization_path = staticmethod(
+        TextToSpeechClient.parse_common_organization_path
+    )
+
+    common_project_path = staticmethod(TextToSpeechClient.common_project_path)
+    parse_common_project_path = staticmethod(
+        TextToSpeechClient.parse_common_project_path
+    )
+
+    common_location_path = staticmethod(TextToSpeechClient.common_location_path)
+    parse_common_location_path = staticmethod(
+        TextToSpeechClient.parse_common_location_path
+    )
+
+    @classmethod
+    def from_service_account_info(cls, info: dict, *args, **kwargs):
+        """Creates an instance of this client using the provided credentials info.
+
+        Args:
+            info (dict): The service account private key info.
+            args: Additional arguments to pass to the constructor.
+            kwargs: Additional arguments to pass to the constructor.
+
+        Returns:
+            TextToSpeechAsyncClient: The constructed client.
+        """
+        return TextToSpeechClient.from_service_account_info.__func__(TextToSpeechAsyncClient, info, *args, **kwargs)  # type: ignore
+
+    @classmethod
+    def from_service_account_file(cls, filename: str, *args, **kwargs):
+        """Creates an instance of this client using the provided credentials
+        file.
+
+        Args:
+            filename (str): The path to the service account private key json
+                file.
+            args: Additional arguments to pass to the constructor.
+            kwargs: Additional arguments to pass to the constructor.
+
+        Returns:
+            TextToSpeechAsyncClient: The constructed client.
+        """
+        return TextToSpeechClient.from_service_account_file.__func__(TextToSpeechAsyncClient, filename, *args, **kwargs)  # type: ignore
+
     from_service_account_json = from_service_account_file
 
+    @property
+    def transport(self) -> TextToSpeechTransport:
+        """Return the transport used by the client instance.
+
+        Returns:
+            TextToSpeechTransport: The transport used by the client instance.
+        """
+        return self._client.transport
+
     get_transport_class = functools.partial(
         type(TextToSpeechClient).get_transport_class, type(TextToSpeechClient)
     )
@@ -56,6 +119,7 @@ class TextToSpeechAsyncClient:
         credentials: credentials.Credentials = None,
         transport: Union[str, TextToSpeechTransport] = "grpc_asyncio",
         client_options: ClientOptions = None,
+        client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiate the text to speech client.
 
@@ -71,16 +135,19 @@ class TextToSpeechAsyncClient:
             client_options (ClientOptions): Custom options for the client. It
                 won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
-                default endpoint provided by the client. GOOGLE_API_USE_MTLS
+                default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
                 environment variable can also be used to override the endpoint:
                 "always" (always use the default mTLS endpoint), "never" (always
-                use the default regular endpoint, this is the default value for
-                the environment variable) and "auto" (auto switch to the default
-                mTLS endpoint if client SSL credentials is present). However,
-                the ``api_endpoint`` property takes precedence if provided.
-                (2) The ``client_cert_source`` property is used to provide client
-                SSL credentials for mutual TLS transport. If not provided, the
-                default SSL credentials will be used if present.
+                use the default regular endpoint) and "auto" (auto switch to the
+                default mTLS endpoint if client certificate is present, this is
+                the default value). However, the ``api_endpoint`` property takes
+                precedence if provided.
+                (2) If GOOGLE_API_USE_CLIENT_CERTIFICATE environment variable
+                is "true", then the ``client_cert_source`` property can be used
+                to provide client certificate for mutual TLS transport. If
+                not provided, the default SSL client certificate will be used if
+                present. If GOOGLE_API_USE_CLIENT_CERTIFICATE is "false" or not
+                set, no client certificate will be used.
 
         Raises:
             google.auth.exceptions.MutualTlsChannelError: If mutual TLS transport
@@ -88,7 +155,10 @@ class TextToSpeechAsyncClient:
         """
 
         self._client = TextToSpeechClient(
-            credentials=credentials, transport=transport, client_options=client_options,
+            credentials=credentials,
+            transport=transport,
+            client_options=client_options,
+            client_info=client_info,
         )
 
     async def list_voices(
@@ -103,20 +173,22 @@ class TextToSpeechAsyncClient:
         r"""Returns a list of Voice supported for synthesis.
 
         Args:
-            request (:class:`~.cloud_tts.ListVoicesRequest`):
+            request (:class:`google.cloud.texttospeech_v1beta1.types.ListVoicesRequest`):
                 The request object. The top-level message sent by the
                 client for the `ListVoices` method.
             language_code (:class:`str`):
                 Optional. Recommended.
                 `BCP-47 <https://www.rfc-editor.org/rfc/bcp/bcp47.txt>`__
-                language tag. If specified, the ListVoices call will
+                language tag. If not specified, the API will return all
+                supported voices. If specified, the ListVoices call will
                 only return voices that can be used to synthesize this
                 language_code. E.g. when specifying "en-NZ", you will
-                get supported "en-\*" voices; when specifying "no", you
+                get supported "en-NZ" voices; when specifying "no", you
                 will get supported "no-\*" (Norwegian) and "nb-\*"
                 (Norwegian Bokmal) voices; specifying "zh" will also get
                 supported "cmn-\*" voices; specifying "zh-hk" will also
-                get supported "yue-\*" voices.
+                get supported "yue-hk" voices.
+
                 This corresponds to the ``language_code`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -128,15 +200,16 @@ class TextToSpeechAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.cloud_tts.ListVoicesResponse:
-                The message returned to the client by the ``ListVoices``
+            google.cloud.texttospeech_v1beta1.types.ListVoicesResponse:
+                The message returned to the client by the ListVoices
                 method.
 
         """
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([language_code]):
+        has_flattened_params = any([language_code])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -155,7 +228,7 @@ class TextToSpeechAsyncClient:
         rpc = gapic_v1.method_async.wrap_method(
             self._client._transport.list_voices,
             default_timeout=None,
-            client_info=_client_info,
+            client_info=DEFAULT_CLIENT_INFO,
         )
 
         # Send the request.
@@ -179,24 +252,27 @@ class TextToSpeechAsyncClient:
         after all text input has been processed.
 
         Args:
-            request (:class:`~.cloud_tts.SynthesizeSpeechRequest`):
+            request (:class:`google.cloud.texttospeech_v1beta1.types.SynthesizeSpeechRequest`):
                 The request object. The top-level message sent by the
                 client for the `SynthesizeSpeech` method.
-            input (:class:`~.cloud_tts.SynthesisInput`):
+            input (:class:`google.cloud.texttospeech_v1beta1.types.SynthesisInput`):
                 Required. The Synthesizer requires
                 either plain text or SSML as input.
+
                 This corresponds to the ``input`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            voice (:class:`~.cloud_tts.VoiceSelectionParams`):
+            voice (:class:`google.cloud.texttospeech_v1beta1.types.VoiceSelectionParams`):
                 Required. The desired voice of the
                 synthesized audio.
+
                 This corresponds to the ``voice`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-            audio_config (:class:`~.cloud_tts.AudioConfig`):
+            audio_config (:class:`google.cloud.texttospeech_v1beta1.types.AudioConfig`):
                 Required. The configuration of the
                 synthesized audio.
+
                 This corresponds to the ``audio_config`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
@@ -208,15 +284,16 @@ class TextToSpeechAsyncClient:
                 sent along with the request as metadata.
 
         Returns:
-            ~.cloud_tts.SynthesizeSpeechResponse:
+            google.cloud.texttospeech_v1beta1.types.SynthesizeSpeechResponse:
                 The message returned to the client by the
-                ``SynthesizeSpeech`` method.
+                SynthesizeSpeech method.
 
         """
         # Create or coerce a protobuf request object.
         # Sanity check: If we got a request object, we should *not* have
         # gotten any keyword arguments that map to the request.
-        if request is not None and any([input, voice, audio_config]):
+        has_flattened_params = any([input, voice, audio_config])
+        if request is not None and has_flattened_params:
             raise ValueError(
                 "If the `request` argument is set, then none of "
                 "the individual field arguments should be set."
@@ -239,7 +316,7 @@ class TextToSpeechAsyncClient:
         rpc = gapic_v1.method_async.wrap_method(
             self._client._transport.synthesize_speech,
             default_timeout=None,
-            client_info=_client_info,
+            client_info=DEFAULT_CLIENT_INFO,
         )
 
         # Send the request.
@@ -250,13 +327,13 @@ class TextToSpeechAsyncClient:
 
 
 try:
-    _client_info = gapic_v1.client_info.ClientInfo(
+    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
         gapic_version=pkg_resources.get_distribution(
             "google-cloud-texttospeech",
         ).version,
     )
 except pkg_resources.DistributionNotFound:
-    _client_info = gapic_v1.client_info.ClientInfo()
+    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
 
 
 __all__ = ("TextToSpeechAsyncClient",)
