@@ -56,6 +56,7 @@ class AudioEncoding(proto.Enum):
     MP3_64_KBPS = 4
     OGG_OPUS = 3
     MULAW = 5
+    ALAW = 6
 
 
 class ListVoicesRequest(proto.Message):
@@ -66,13 +67,14 @@ class ListVoicesRequest(proto.Message):
         language_code (str):
             Optional. Recommended.
             `BCP-47 <https://www.rfc-editor.org/rfc/bcp/bcp47.txt>`__
-            language tag. If specified, the ListVoices call will only
-            return voices that can be used to synthesize this
+            language tag. If not specified, the API will return all
+            supported voices. If specified, the ListVoices call will
+            only return voices that can be used to synthesize this
             language_code. E.g. when specifying "en-NZ", you will get
-            supported "en-\*" voices; when specifying "no", you will get
+            supported "en-NZ" voices; when specifying "no", you will get
             supported "no-\*" (Norwegian) and "nb-\*" (Norwegian Bokmal)
             voices; specifying "zh" will also get supported "cmn-\*"
-            voices; specifying "zh-hk" will also get supported "yue-\*"
+            voices; specifying "zh-hk" will also get supported "yue-hk"
             voices.
     """
 
@@ -83,7 +85,7 @@ class ListVoicesResponse(proto.Message):
     r"""The message returned to the client by the ``ListVoices`` method.
 
     Attributes:
-        voices (Sequence[~.cloud_tts.Voice]):
+        voices (Sequence[google.cloud.texttospeech_v1beta1.types.Voice]):
             The list of voices.
     """
 
@@ -101,7 +103,7 @@ class Voice(proto.Message):
         name (str):
             The name of this voice.  Each distinct voice
             has a unique name.
-        ssml_gender (~.cloud_tts.SsmlVoiceGender):
+        ssml_gender (google.cloud.texttospeech_v1beta1.types.SsmlVoiceGender):
             The gender of this voice.
         natural_sample_rate_hertz (int):
             The natural sample rate (in hertz) for this
@@ -122,18 +124,18 @@ class SynthesizeSpeechRequest(proto.Message):
     ``SynthesizeSpeech`` method.
 
     Attributes:
-        input (~.cloud_tts.SynthesisInput):
+        input (google.cloud.texttospeech_v1beta1.types.SynthesisInput):
             Required. The Synthesizer requires either
             plain text or SSML as input.
-        voice (~.cloud_tts.VoiceSelectionParams):
+        voice (google.cloud.texttospeech_v1beta1.types.VoiceSelectionParams):
             Required. The desired voice of the
             synthesized audio.
-        audio_config (~.cloud_tts.AudioConfig):
+        audio_config (google.cloud.texttospeech_v1beta1.types.AudioConfig):
             Required. The configuration of the
             synthesized audio.
-        enable_time_pointing (Sequence[~.cloud_tts.SynthesizeSpeechRequest.TimepointType]):
-            Whether and what timepoints should be
-            returned in the response.
+        enable_time_pointing (Sequence[google.cloud.texttospeech_v1beta1.types.SynthesizeSpeechRequest.TimepointType]):
+            Whether and what timepoints are returned in
+            the response.
     """
 
     class TimepointType(proto.Enum):
@@ -199,7 +201,7 @@ class VoiceSelectionParams(proto.Message):
             The name of the voice. If not set, the service will choose a
             voice based on the other parameters such as language_code
             and gender.
-        ssml_gender (~.cloud_tts.SsmlVoiceGender):
+        ssml_gender (google.cloud.texttospeech_v1beta1.types.SsmlVoiceGender):
             The preferred gender of the voice. If not set, the service
             will choose a voice based on the other parameters such as
             language_code and name. Note that this is only a preference,
@@ -219,7 +221,7 @@ class AudioConfig(proto.Message):
     r"""Description of audio data to be synthesized.
 
     Attributes:
-        audio_encoding (~.cloud_tts.AudioEncoding):
+        audio_encoding (google.cloud.texttospeech_v1beta1.types.AudioEncoding):
             Required. The format of the audio byte
             stream.
         speaking_rate (float):
@@ -287,11 +289,11 @@ class SynthesizeSpeechResponse(proto.Message):
             include the WAV header. Note: as with all bytes fields,
             protobuffers use a pure binary representation, whereas JSON
             representations use base64.
-        timepoints (Sequence[~.cloud_tts.Timepoint]):
+        timepoints (Sequence[google.cloud.texttospeech_v1beta1.types.Timepoint]):
             A link between a position in the original request input and
             a corresponding time in the output audio. It's only
             supported via ``<mark>`` of SSML input.
-        audio_config (~.cloud_tts.AudioConfig):
+        audio_config (google.cloud.texttospeech_v1beta1.types.AudioConfig):
             The audio metadata of ``audio_content``.
     """
 
@@ -299,7 +301,7 @@ class SynthesizeSpeechResponse(proto.Message):
 
     timepoints = proto.RepeatedField(proto.MESSAGE, number=2, message="Timepoint",)
 
-    audio_config = proto.Field(proto.MESSAGE, number=4, message=AudioConfig,)
+    audio_config = proto.Field(proto.MESSAGE, number=4, message="AudioConfig",)
 
 
 class Timepoint(proto.Message):
